@@ -1,4 +1,8 @@
 package AnyEvent::Subprocess::Easy;
+BEGIN {
+  $AnyEvent::Subprocess::Easy::VERSION = '1.102910';
+}
+# ABSTRACT: wrappers around AnyEvent::Subprocess to save typing in simple cases
 use strict;
 use warnings;
 
@@ -67,12 +71,18 @@ sub qx_nonblock {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 AnyEvent::Subprocess::Easy - wrappers around AnyEvent::Subprocess to save typing in simple cases
 
+=head1 VERSION
+
+version 1.102910
+
 =head1 SYNOPSIS
 
     use AnyEvent::Subprocess::Easy qw(qx_nonblock);
@@ -113,3 +123,20 @@ patterns!
 =head1 SEE ALSO
 
 L<AnyEvent::Subprocess|AnyEvent::Subprocess>
+
+=head1 AUTHOR
+
+Jonathan Rockway <jrockway@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Jonathan Rockway <jrockway@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
