@@ -1,4 +1,8 @@
 package AnyEvent::Subprocess::Handle;
+BEGIN {
+  $AnyEvent::Subprocess::Handle::VERSION = '1.102910';
+}
+# ABSTRACT: AnyEvent::Handle subclass with some additional methods for AnyEvent::Subprocess
 use strict;
 use warnings;
 use AnyEvent;
@@ -84,11 +88,17 @@ sub destroy {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-AnyEvent::Subprocess::Handle - C<AnyEvent::Handle> subclass
+AnyEvent::Subprocess::Handle - AnyEvent::Handle subclass with some additional methods for AnyEvent::Subprocess
+
+=head1 VERSION
+
+version 1.102910
 
 =head1 DESCRIPTION
 
@@ -105,3 +115,20 @@ to the constructor.
 =head2 close_fh
 
 Closes the underlying filehandle, sending EOF to the child process.
+
+=head1 AUTHOR
+
+Jonathan Rockway <jrockway@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Jonathan Rockway <jrockway@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
