@@ -1,4 +1,8 @@
 package AnyEvent::Subprocess::Job::Delegate::CaptureHandle;
+BEGIN {
+  $AnyEvent::Subprocess::Job::Delegate::CaptureHandle::VERSION = '1.102910';
+}
+# ABSTRACT: capture the data that comes in via a handle
 use Moose;
 use AnyEvent::Subprocess::Running::Delegate::CaptureHandle;
 
@@ -38,12 +42,18 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 AnyEvent::Subprocess::Job::Delegate::CaptureHandle - capture the data that comes in via a handle
 
+=head1 VERSION
+
+version 1.102910
+
 =head1 DESCRIPTION
 
 If you have a Handle delegate and just want to save the output
@@ -56,3 +66,20 @@ output available via the Done instance.
 =head2 handle
 
 The name of the handle you want to capture's delegate.
+
+=head1 AUTHOR
+
+Jonathan Rockway <jrockway@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Jonathan Rockway <jrockway@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
