@@ -1,4 +1,8 @@
 package AnyEvent::Subprocess::Types;
+BEGIN {
+  $AnyEvent::Subprocess::Types::VERSION = '1.102910';
+}
+# ABSTRACT: C<MooseX::Types> used internally
 use MooseX::Types -declare => [ qw{
     Direction
     JobDelegate
@@ -39,12 +43,18 @@ enum WhenToCallBack, qw/Readable Line/;
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 AnyEvent::Subprocess::Types - C<MooseX::Types> used internally
 
+=head1 VERSION
+
+version 1.102910
+
 =head1 TYPES
 
     Direction
@@ -52,3 +62,22 @@ AnyEvent::Subprocess::Types - C<MooseX::Types> used internally
     RunDelegate
     DoneDelegate
     SubprocessCode
+    CodeList
+    WhenToCallBack
+
+=head1 AUTHOR
+
+Jonathan Rockway <jrockway@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Jonathan Rockway <jrockway@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
